/*Intergenerational analysis*/

set more off, perm

cd "/disk/bulkw/zachward/cens1930.work/ImmigrantMulti/"

/****************************************************************************/
use "data/cleaned188019101940.dta", clear


preserve

	replace weight188019101940=. if num!=1
	collapse (sum) weight188019101940, by(county_G11880 statefip_G11880 bpl_G11880) fast
	drop if bpl==.
	gen gisjoin="G"+string(statefip, "%02.0f")+string(county, "%05.0f")
	reshape wide weight188019101940, i(gisjoin statefip county) j(bpl)
	keep gisjoin *453 *414
	recode weight188019101940414 weight188019101940453 (missing=0)
	export delimited using "tables/nhgisjoinchildren1940_G3", replace nolabel 
restore


preserve
	
	collapse (sum) weight188019101940, by(county_G31940 statefip_G31940 bpl_G11880) fast
	drop if bpl==.
	gen gisjoin="G"+string(statefip, "%02.0f")+string(county, "%05.0f")
	reshape wide weight188019101940, i(gisjoin statefip county) j(bpl)
	keep gisjoin  *453 *414

	recode weight188019101940414 weight188019101940453 (missing=0)
	export delimited using "tables/nhgisjoinchildren1880_G1", replace nolabel 
restore

preserve
	capture drop ind
	gen ind=1
	duplicates drop serial_G21880 pernum_G11880, force


	collapse lsobekscore_G11880 (rawsum) ind [pw=weight188019101940], by(bpl_G11880)
	
	outsheet using "tables/1880firstgen", replace
restore	

preserve
	capture drop ind
	gen ind=1
	duplicates drop serial_G21910 pernum_G21910, force


	collapse lsobekscore_G21910 (rawsum) ind [pw=weight188019101940], by(bpl_G11880)
	outsheet using "tables/1910secondgen", replace
restore	

preserve
	capture drop ind
	gen ind=1

	collapse lsobekscore_G31940 (rawsum) ind [pw=weight188019101940], by(bpl_G11880)
	outsheet using "tables/1940thirdgen", replace
restore	

egen enumdist_G1=group(statefip_G11880 county_G11880 enumdist_G1)
egen countygroup_G2=group(statefip_G21910 county_G21910 enumdist_G21910)

egen countygroupalt_G1=group(statefip_G11880 county_G11880)


gen indiv=1

/*Group averages*/

sort serial_G21910 pernum_G21910
by serial_G21910 pernum_G21910: gen nG2=_n

foreach xvar in farmer wc prof sales skilled unskilled servicelow lab oper loccscore loccscore1880 lcls lcwscore{
	replace `xvar'_G21910=. if nG2>1
}


/*Any differences between the larger and smaller linked samples?*/

capture erase "tables/18801910.xml"	
capture erase "tables/18801910.txt"	

foreach xvar in farmer wc skilled unskilled lsobekscore loccscore{
	reg `xvar'_G21910 c.`xvar'_G11880##c.age40*G2* c.age40_G1* [pw=weight188019101940], cluster(serial_G21880)
	capture outreg2 using "tables/18801910", excel append noas keep(`xvar'_G11880) dec(3)
	
	reg `xvar'_G21910 c.`xvar'_G11880##c.age40*G2* c.age40_G1* `xvar'CLPSDbar1 [pw=weight188019101940], cluster(serial_G21880)
	lincom `xvar'_G11880+`xvar'CLPSDbar1
	capture outreg2 using "tables/18801910", excel append noas adds(joint,r(estimate), standarderror,r(se)) keep(`xvar'_G11880 `xvar'CLPSDbar1) dec(3)
	
	capture areg `xvar'_G21910 c.`xvar'_G11880##c.age40*G2* c.age40_G1* `xvar'CLPSDbar1 [pw=weight188019101940], cluster(serial_G21880) a(enumdist_G1)
	lincom `xvar'_G11880+`xvar'CLPSDbar1
	capture outreg2 using "tables/18801910", excel append noas adds(joint,r(estimate), standarderror,r(se)) keep(`xvar'_G11880 `xvar'CLPSDbar1) dec(3)


}

/*Three generations*/

use "data/cleaned188019101940.dta", clear

egen enumdist_G1=group(statefip_G11880 county_G11880 enumdist_G1)

egen countygroupalt_G1=group(statefip_G11880 county_G11880)


duplicates tag enumdist_G1, gen(dup_enumdist)
/*Generate variable for mixed ethnic enumeration district*/
gen indiv=1
egen total_enum1880=total(indiv), by(enumdist_G1)
egen total_enum1880_bpl=total(indiv), by(enumdist_G1 bpl_G11880)
gen mixedneighbor=total_enum1880-total_enum1880_bpl>0
egen countygroup_G2=group(statefip_G21910 county_G21910 enumdist_G21910)


egen total_county1880=total(indiv), by(countygroupalt_G1)
egen total_county1880_bpl=total(indiv), by(countygroupalt_G1 bpl_G11880)
gen mixedneighbor_county=total_county1880-total_county1880_bpl>0

capture erase "tables/19101940.xml"	
capture erase "tables/19101940.txt"	
	
foreach xvar in farmer wc skilled unskilled lsobekscore loccscore{
	reg `xvar'_G31940 c.`xvar'_G21910##c.age40*G3* c.age40*G2* [pw=weight188019101940], cluster(serial_G31910)
	capture outreg2 using "tables/19101940", excel append noas keep(`xvar'_G21910) dec(3)

	reg `xvar'_G31940 c.`xvar'_G21910##c.age40*G3* c.age40*G2* `xvar'CLPSDbar2 [pw=weight188019101940], cluster(serial_G31910)
	lincom `xvar'_G21910+`xvar'CLPSDbar2
	capture outreg2 using "tables/19101940", excel append noas adds(joint,r(estimate), standarderror,r(se)) keep(`xvar'_G21910 `xvar'CLPSDbar2) dec(3)

	capture areg `xvar'_G31940 c.`xvar'_G21910##c.age40*G3* c.age40*G2* `xvar'CLPSDbar2 [pw=weight188019101940], cluster(serial_G31910) a(countygroup_G2)
	lincom `xvar'_G21910+`xvar'CLPSDbar2
	capture outreg2 using "tables/19101940", excel append noas adds(joint,r(estimate), standarderror,r(se)) keep(`xvar'_G21910 `xvar'CLPSDbar2) dec(3)
}

	
	
/*************Test the two models together.******************/
	
drop num
sort serial_G31910 pernum_G21910
by serial_G31910 pernum_G21910: gen num=_n
					
foreach xvar in farmer wc prof sales skilled unskilled servicelow lab oper loccscore loccscore1880 lcwscore lsobekscore loccscore_nf loccsc1880_nf lcwscore_nf lsobekscore_nf{
	reg `xvar'_G21910 c.`xvar'_G11880##c.age40*G2* c.age40*G1* `xvar'CLPSDbar1 if num==1 [iw=weight188019101940]
	est store `xvar'18801910
}
		
		
foreach xvar in farmer wc prof sales skilled unskilled servicelow lab oper loccscore loccscore1880 lcwscore lsobekscore loccscore_nf loccsc1880_nf lcwscore_nf lsobekscore_nf{
	reg `xvar'_G31940 c.`xvar'_G21910##c.age40*G3* c.age40*G2* `xvar'CLPSDbar2 [iw=weight188019101940]
	est store `xvar'19101940
}
	
foreach xvar in farmer wc prof sales skilled unskilled servicelow lab oper loccscore loccscore1880 lcwscore lsobekscore loccscore_nf loccsc1880_nf lcwscore_nf lsobekscore_nf{
	reg `xvar'_G31940 c.`xvar'_G11880##c.age40*G3* c.age40_G1* `xvar'CLPSDbar1 [iw=weight188019101940]
	est store `xvar'18801940
}
	

capture erase "tables/predictedactual.xml"
capture erase "tables/predictedactual.txt"

foreach xvar in farmer wc skilled unskilled lsobekscore loccscore{

	qui suest `xvar'18801910 `xvar'19101940 `xvar'18801940, cluster(serial_G21880)
	
	
	nlcom ([`xvar'18801910_mean]`xvar'CLPSDbar1*[`xvar'19101940_mean]`xvar'CLPSDbar2)+ ///
	[`xvar'18801910_mean]`xvar'_G11880*[`xvar'19101940_mean]`xvar'CLPSDbar2+ ///
	[`xvar'19101940_mean]`xvar'_G21910*[`xvar'18801910_mean]`xvar'CLPSDbar1 
	matrix define `xvar'1=r(b)
	matrix define `xvar'2=r(V)
	scalar `xvar'iterethnicAR1=`xvar'1[1,1]
	scalar `xvar'iterethnicAR1se=(`xvar'2[1,1])^.5
	
	nlcom [`xvar'18801910_mean]`xvar'_G11880*[`xvar'19101940_mean]`xvar'_G21910
	matrix define `xvar'3=r(b)
	matrix define `xvar'4=r(V)
	scalar `xvar'iterGPAAR1=`xvar'3[1,1]
	scalar `xvar'iterGPAAR1se=(`xvar'4[1,1])^.5
	
	nlcom ([`xvar'18801910_mean]`xvar'CLPSDbar1*[`xvar'19101940_mean]`xvar'CLPSDbar2)+ ///
	[`xvar'18801910_mean]`xvar'_G11880*[`xvar'19101940_mean]`xvar'CLPSDbar2+ ///
	[`xvar'19101940_mean]`xvar'_G21910*[`xvar'18801910_mean]`xvar'CLPSDbar1 ///
	+ [`xvar'18801910_mean]`xvar'_G11880*[`xvar'19101940_mean]`xvar'_G21910
	matrix define `xvar'5=r(b)
	matrix define `xvar'6=r(V)
	scalar `xvar'itermeanAR1=`xvar'5[1,1]
	scalar `xvar'itermeanAR1se=(`xvar'6[1,1])^.5
		
		/*test ethnic capital effect across AR1 and actual model*/
	nlcom (ar1ethnic: [`xvar'18801910_mean]`xvar'CLPSDbar1*[`xvar'19101940_mean]`xvar'CLPSDbar2+ ///
	[`xvar'18801910_mean]`xvar'_G11880*[`xvar'19101940_mean]`xvar'CLPSDbar2+ ///
	[`xvar'19101940_mean]`xvar'_G21910*[`xvar'18801910_mean]`xvar'CLPSDbar1) /// 
	(actualethnic: [`xvar'18801940_mean]`xvar'CLPSDbar1), post
	test _b[ar1ethnic]=_b[actualethnic]
	scalar pethnic`xvar'=r(p)
		
		/*test grandpa effect across AR1 and actual model*/

	qui suest `xvar'18801910 `xvar'19101940 `xvar'18801940, cluster(serial_G21880)
		
	nlcom (ar1gpa: [`xvar'18801910_mean]`xvar'_G11880*[`xvar'19101940_mean]`xvar'_G21910) ///
	(actualgpa: [`xvar'18801940_mean]`xvar'_G11880), post
	test _b[ar1gpa]=_b[actualgpa]	
	scalar pgpa`xvar'=r(p)
		
	/*test mean convergence across AR1 and actual model*/

	qui suest `xvar'18801910 `xvar'19101940 `xvar'18801940, cluster(serial_G21880)
	
	nlcom (ar1mean: [`xvar'18801910_mean]`xvar'CLPSDbar1*[`xvar'19101940_mean]`xvar'CLPSDbar2+ ///
	[`xvar'18801910_mean]`xvar'_G11880*[`xvar'19101940_mean]`xvar'CLPSDbar2 + ///
	[`xvar'19101940_mean]`xvar'_G21910*[`xvar'18801910_mean]`xvar'CLPSDbar1 + /// 
	[`xvar'18801910_mean]`xvar'_G11880*[`xvar'19101940_mean]`xvar'_G21910) ///
	(actualmean: [`xvar'18801940_mean]`xvar'CLPSDbar1+[`xvar'18801940_mean]`xvar'_G11880), post
	test _b[ar1mean]=_b[actualmean]
	scalar pmean`xvar'=r(p)
	
	
	capture outreg2 using "tables/predictedactual", excel append ///
	adds(iterativemean,`xvar'itermeanAR1, iterativese, `xvar'itermeanAR1se, ///
	iterativegrandpa,`xvar'iterGPAAR1, iterativegrandpaSE,`xvar'iterGPAAR1se, /// 
	iterativeethnic,`xvar'iterethnicAR1, iterativeethnicse, `xvar'iterethnicAR1se, ///
	pvalueethnic, pethnic`xvar', pvaluegpa, pgpa`xvar', pmean, pmean`xvar') ctitle(`xvar') dec(3) noas
	scalar drop _all 

}
	

capture erase "tables/18801940.xml"	
capture erase "tables/18801940.txt"	

capture erase "tables/18801940euro.xml"	
capture erase "tables/18801940euro.txt"	

gen main=bpl_G11880==400 | bpl_G11880==404 | bpl_G11880==405 | bpl_G11880==410 | bpl_G11880==411 | ///
	bpl_G11880==414 | bpl_G11880==420 | bpl_G11880==421 | bpl_G11880==425 | ///
	bpl_G11880==426 | bpl_G11880==434 | bpl_G11880==436 | bpl_G11880==438 | bpl_G11880==450 | ///
	bpl_G11880==453 | bpl_G11880==465
	

	
	
foreach xvar in farmer wc skilled unskilled lsobekscore loccscore{

	reg `xvar'_G31940 c.`xvar'_G11880##c.age40*G3* c.age40_G1* [pw=weight188019101940], cluster(serial_G21880)
	capture outreg2 using "tables/18801940", excel append noas keep(`xvar'_G11880) dec(3)

	reg `xvar'_G31940 c.`xvar'_G11880##c.age40*G3* c.age40_G1* `xvar'CLPSDbar1 [pw=weight188019101940], cluster(serial_G21880)
	lincom `xvar'_G11880+`xvar'CLPSDbar1
	capture outreg2 using "tables/18801940", excel append noas adds(joint,r(estimate), standarderror,r(se)) keep(`xvar'_G11880 `xvar'CLPSDbar1) dec(3)
	
	capture areg `xvar'_G31940 c.`xvar'_G11880##c.age40*G3* c.age40_G1* `xvar'CLPSDbar1 [pw=weight188019101940], a(enumdist_G1)
	lincom `xvar'_G11880+`xvar'CLPSDbar1
	capture outreg2 using "tables/18801940", excel append noas adds(joint,r(estimate), standarderror,r(se)) keep(`xvar'_G11880 `xvar'CLPSDbar1) dec(3)

	capture areg `xvar'_G31940 c.`xvar'_G11880##c.age40*G3* c.age40_G1* `xvar'CLPSDbar1 [pw=weight188019101940], a(countygroupalt_G1)
	lincom `xvar'_G11880+`xvar'CLPSDbar1
	capture outreg2 using "tables/18801940", excel append noas adds(joint,r(estimate), standarderror,r(se)) keep(`xvar'_G11880 `xvar'CLPSDbar1) dec(3)
	
}	

foreach xvar in farmer wc skilled unskilled lsobekscore loccscore{

	reg `xvar'_G31940 c.`xvar'_G11880##c.age40*G3* c.age40_G1* if floor(bpl_G11880/100)==4 [pw=weight188019101940], cluster(serial_G21880)
	capture outreg2 using "tables/18801940euro", excel append noas keep(`xvar'_G11880) dec(3)

	reg `xvar'_G31940 c.`xvar'_G11880##c.age40*G3* c.age40_G1* `xvar'CLPSDbar1 if floor(bpl_G11880/100)==4 [pw=weight188019101940], cluster(serial_G21880)
	lincom `xvar'_G11880+`xvar'CLPSDbar1
	capture outreg2 using "tables/18801940euro", excel append noas adds(joint,r(estimate), standarderror,r(se)) keep(`xvar'_G11880 `xvar'CLPSDbar1) dec(3)
	
	
}	

capture erase "tables/18801940robust.xml"	
capture erase "tables/18801940robust.txt"	


reg educyears_G31940 c.literate_G11880##c.age40*G3* c.age40_G1* literateCLPSDbar1 [pw=weight188019101940], cluster(serial_G21880)
lincom literate_G11880+literateCLPSDbar1
capture outreg2 using "tables/18801940robust", excel append noas adds(joint,r(estimate), standarderror,r(se)) keep(literate_G11880 literateCLPSDbar1)  dec(3)

reg lincwage c.lsobekscore_G11880##c.age40*G3* c.age40_G1* lsobekscoreCLPSDbar1 [pw=weight188019101940], cluster(serial_G21880)
lincom lsobekscore_G11880+lsobekscoreCLPSDbar1
capture outreg2 using "tables/18801940robust", excel append noas adds(joint,r(estimate), standarderror,r(se)) keep(lsobekscore_G11880 lsobekscoreCLPSDbar1)  dec(3)



foreach xvar in lsobekscore_nf farmer prof sales skilled servicelow lab oper loccscore1880 lcwscore {

	reg `xvar'_G31940 c.`xvar'_G11880##c.age40*G3* c.age40_G1* `xvar'CLPSDbar1 [pw=weight188019101940], cluster(serial_G21880)
	lincom `xvar'_G11880+`xvar'CLPSDbar1
	capture outreg2 using "tables/18801940robust", excel append noas adds(joint,r(estimate), standarderror,r(se)) keep(`xvar'_G11880 `xvar'CLPSDbar1)  dec(3)
	
}

	reg lclsadj_G31940 c.loccscore1880_G11880##c.age40*G3* c.age40_G1* loccscore1880CLPSDbar1 [pw=weight188019101940], cluster(serial_G21880)
	lincom loccscore1880_G11880+loccscore1880CLPSDbar1
	capture outreg2 using "tables/18801940robust", excel append noas adds(joint,r(estimate), standarderror,r(se)) keep(loccscore1880_G11880 loccscore1880CLPSDbar1)  dec(3)
	
	reg lsobekscore_nf_G31940 c.lsobekscore_nf_G11880##c.age40*G3* c.age40_G1* lsobekscore_nfCLPSDbar1 [pw=weight188019101940], cluster(serial_G21880) 
	lincom lsobekscore_nf_G11880+lsobekscore_nfCLPSDbar1
	capture outreg2 using "tables/18801940robust", excel append noas adds(joint,r(estimate), standarderror,r(se)) keep(lsobekscore_nf_G11880 lsobekscore_nfCLPSDbar1)  dec(3)

	
	areg lsobekscore_nf_G31940 c.lsobekscore_nf_G11880##c.age40*G3* c.age40_G1* lsobekscore_nfCLPSDbar1 [pw=weight188019101940], cluster(serial_G21880) a(enumdist_G1)
	lincom lsobekscore_nf_G11880+lsobekscore_nfCLPSDbar1
	capture outreg2 using "tables/18801940robust", excel append noas adds(joint,r(estimate), standarderror,r(se)) keep(lsobekscore_nf_G11880 lsobekscore_nfCLPSDbar1)  dec(3)
	
	reg loccscore_nf_G31940 c.loccscore_nf_G11880##c.age40*G3* c.age40_G1* loccscore_nfCLPSDbar1 [pw=weight188019101940], cluster(serial_G21880) 
	lincom loccscore_nf_G11880+loccscore_nfCLPSDbar1
	capture outreg2 using "tables/18801940robust", excel append noas adds(joint,r(estimate), standarderror,r(se)) keep(loccscore_nf_G11880 loccscore_nfCLPSDbar1)  dec(3)

	
	areg loccscore_nf_G31940 c.loccscore_nf_G11880##c.age40*G3* c.age40_G1* loccscore_nfCLPSDbar1 [pw=weight188019101940], cluster(serial_G21880) a(enumdist_G1)
	lincom loccscore_nf_G11880+loccscore_nfCLPSDbar1
	capture outreg2 using "tables/18801940robust", excel append noas adds(joint,r(estimate), standarderror,r(se)) keep(loccscore_nf_G11880 loccscore_nfCLPSDbar1)  dec(3)

	
	
gen probitmax=probithat_18801910+probithat_19101940
su probitmax, detail
gen highprobit=probitmax>=r(p50)


capture erase "tables/18801940altsample.xml"	
capture erase "tables/18801940altsample.txt"	

foreach xvar in lsobekscore{

	reg `xvar'_G31940 c.`xvar'_G11880##c.age40*G3* c.age40_G1* `xvar'CLPSDbar1 [pw=weight188019101940], cluster(serial_G21880)
	lincom `xvar'_G11880+`xvar'CLPSDbar1
	capture outreg2 using "tables/18801940altsample", excel append noas adds(joint,r(estimate), standarderror,r(se)) keep(`xvar'_G11880 `xvar'CLPSDbar1)  dec(3)
	
	reg `xvar'_G31940 c.`xvar'_G11880##c.age40*G3* c.age40_G1* `xvar'CLPSDbar1 if highprobit==1 [pw=weight188019101940], cluster(serial_G21880)
	lincom `xvar'_G11880+`xvar'CLPSDbar1
	capture outreg2 using "tables/18801940altsample", excel append noas adds(joint,r(estimate), standarderror,r(se)) keep(`xvar'_G11880 `xvar'CLPSDbar1) ctitle("High Prob")   dec(3)

	reg `xvar'_G31940 c.`xvar'_G11880##c.age40*G3* c.age40_G1* `xvar'CLPSDbar1 if floor(bpl_G11880/100)==4 [pw=weight188019101940], cluster(serial_G21880)  
	lincom `xvar'_G11880+`xvar'CLPSDbar1
	capture outreg2 using "tables/18801940altsample", excel append noas adds(joint,r(estimate), standarderror,r(se)) keep(`xvar'_G11880 `xvar'CLPSDbar1) ctitle("Keep Euro") dec(3)
	
	reg `xvar'_G31940 c.`xvar'_G11880##c.age40*G3* c.age40_G1* `xvar'CLPSDbar1 if bpl_G1!=200 [pw=weight188019101940], cluster(serial_G21880)  
	lincom `xvar'_G11880+`xvar'CLPSDbar1
	capture outreg2 using "tables/18801940altsample", excel append noas adds(joint,r(estimate), standarderror,r(se)) keep(`xvar'_G11880 `xvar'CLPSDbar1) ctitle("Drop Mex") dec(3)
	
	
}

capture erase "tables/18801940ar2.xml"	
capture erase "tables/18801940ar2.txt"	


foreach xvar in farmer wc skilled unskilled lsobekscore loccscore{
	
	reg `xvar'_G31940 c.`xvar'_G21910##c.age40*G3* c.age40_G2* c.`xvar'_G11880##c.age40*G3* c.age40_G1* `xvar'CLPSDbar2 `xvar'CLPSDbar1 [pw=weight188019101940], cluster(serial_G21880)
	lincom `xvar'_G11880+`xvar'CLPSDbar1
	scalar `xvar'joint1880=r(estimate)
	scalar `xvar'sd1880=r(se)

	lincom `xvar'_G21910+`xvar'CLPSDbar2
	scalar `xvar'joint1910=r(estimate)
	scalar `xvar'sd1910=r(se)

	outreg2 using "tables/18801940ar2", excel append noas adds(joint1880, `xvar'joint1880, ///
	standarderror1880, `xvar'sd1880, joint1910, `xvar'joint1910, standarderror1910, ///
	`xvar'sd1910) ///
	keep(`xvar'_G11880 `xvar'_G21910 `xvar'CLPSDbar2 `xvar'CLPSDbar1) sortvar(`xvar'_G21910 `xvar'CLPSDbar2 `xvar'_G11880 `xvar'CLPSDbar1)

	scalar drop _all
	
}

/*Neighborhood analysis*/

capture erase "tables/18801940robustED.xml"	
capture erase "tables/18801940robustED.txt"	

foreach xvar in farmer wc skilled unskilled lsobekscore loccscore{
			
	reg `xvar'_G31940 c.`xvar'_G11880##c.age40*G3* c.age40_G1* `xvar'barED1 [pw=weight188019101940], cluster(serial_G21880)
	lincom `xvar'_G11880+`xvar'barED1
	outreg2 using "tables/18801940robustED", excel append noas adds(joint,r(estimate), standarderror,r(se)) keep(`xvar'_G11880 `xvar'barED1) dec(3) 

	areg `xvar'_G31940 c.`xvar'_G11880##c.age40*G3* c.age40_G1* `xvar'barED1 [pw=weight188019101940], cluster(serial_G21880) a(enumdist_G1)
	lincom `xvar'_G11880+`xvar'barED1
	outreg2 using "tables/18801940robustED", excel append noas adds(joint,r(estimate), standarderror,r(se)) keep(`xvar'_G11880 `xvar'barED1) ctitle("ED FE") dec(3)

}
