/*Keep links 1880-1910*/


set more off, perm

cd "/disk/bulkw/zachward/cens1930.work/1880linkforward/"

/*First use the 1880-1910 linked data, attach the 1910 outcomes.*/

use 18801910linkedppv90.dta, clear

/*Keep only second-generation sons*/
keep if fbpl_G21880>100 & bpl<100 

keep serial* pernum* probithat jwfirstdist jwlastdist
rename probithat probithat_18801910
rename serial_G21910 serial
rename pernum_G21910 pernum

/*Drop duplicate matches*/
duplicates tag serial pernum, gen(dups)
drop if dups>0
drop dups

/*Merge to 1910 to retrieve adult outcomes*/
merge 1:1 serial pernum using  "/disk/bulkw/zachward/cens1930.work/1910census/1910natives_adult.dta"
keep if _merge==3
drop _merge

foreach xvar of varlist _all{
	rename `xvar' `xvar'_G21910
}

rename serial_G21880 serial_G21880
rename pernum_G21880 pernum_G21880
rename probithat_18801910 probithat_18801910
rename jwfirst jwfirst
rename jwlast jwlast

saveold "18801910linkedto1910.dta", replace


/**************Linking the 1910 to 1940*********************/


cd "/disk/bulkw/zachward/cens1930.work/1880linkforward/"

/*This is the second link from 1910-1940. Attach both childhood characteristics
from 1910 and adult characteristics from 1940 to the file*/

use "/disk/bulkw/zachward/cens1930.work/1910census/19101940linkedppv90.dta", clear

keep serial* pernum* probithat jwfirstdist jwlastdist
rename probithat probithat_19101940

rename serial_G31910 serial
rename pernum_G31910 pernum
duplicates tag serial pernum, gen(dups)
drop if dups>0
drop dups

/*Attach childhood characteristics*/
merge 1:1 serial pernum using "/disk/bulkw/zachward/cens1930.work/1910census/1910natives_pop_child.dta"
keep if _merge==3
drop _merge

foreach xvar of varlist _all{
	rename `xvar' `xvar'_G31910
}

rename serial_G31940  serial_G31940
rename pernum_G31940 pernum_G31940
rename probithat_19101940 probithat_19101940
rename jwfirst jwfirst
rename jwlast jwlast

rename serial_G31940 serial
rename pernum_G31940 pernum

duplicates tag serial pernum, gen(dups)
drop if dups>0
drop dups

/*Attach adult characteristics*/
 
merge 1:1 serial pernum using  "/disk/bulkw/zachward/cens1940.work/1940census/1940natives_adult.dta"
keep if _merge==3
drop _merge

foreach xvar of varlist year-yob{
	rename `xvar' `xvar'_G31940
}

rename serial serial_G31940
rename pernum pernum_G31940

saveold "19101940linkedfatherson.dta", replace

/*Pair the two up by connecting the poploc from childhood gen41910
with the person number from gen31910*/


use 19101940linkedfatherson_nov29, clear
rename pernum_G31910 pernum_origgen41910
rename poploc_G31910 pernum_G21910
gen serial_G21910=serial_G31910
/*Many sons in 1910 may have one father in 1910, matched up
by changing the poploc for the son to the pernum*/

merge m:1 serial_G21910 pernum_G21910 using 18801910linkedto1910_nov29.dta
keep if _merge==3
drop _merge

drop name*
compress
saveold "188019101940linkedgrandfatherson_nov29.dta", replace


/****Merge with the 1880 data******/

use "/disk/bulkw/zachward/cens1930.work/1880linkforward/1880fullpop.dta", clear

keep if sex==1
rename bpl bpld
rename mbpl mbpld
rename fbpl fbpld

gen bpl=floor(bpld/100)
gen fbpl=floor(fbpld/100)
gen mbpl=floor(mbpld/100)

preserve
	keep if age>=30 & age<=55
	keep if bpl>100
	keep lit occ1950 age sex serial pernum bpl fbpl mbpl region statefip enumdist county ind1950 race occscore
	foreach xvar of varlist _all{
		rename `xvar' `xvar'_G11880
	}
	rename serial serial
	rename pernum pernum
	saveold 1880popinfo.dta, replace
restore

keep if age<=14
keep if bpl<100

rename pernum pernum_orig
rename poploc pernum
merge m:1 serial pernum using 1880popinfo.dta
keep if _merge==3
drop _merge

foreach xvar of varlist sample-bpl{
	rename `xvar' `xvar'_G21880
}

rename pernum_G21880 pernum_G11880
rename pernum_orig pernum_G21880

merge 1:m serial_G21880 pernum_G21880 using "188019101940linkedgrandfatherson.dta"
keep if _merge==3
drop _merge


save "/disk/bulkw/zachward/cens1930.work/ImmigrantMulti/data/188019101940_G3_G2_G1.dta", replace





