/*This file builds the set of potential links between 1880 and 1910 census
based on the Feigenbaum (2016) method. */

cd "/disk/bulkw/zachward/cens1930.work/1880linkforward/"


use age namefrst namelast sex serial race pernum mbpl* fbpl* bpl ///
	if age<=14 using "/disk/bulkw/zachward/cens1930.work/1910census/1880children.dta", clear

gen yob=1880-age
	replace fname=upper(fname)
	gen fnameclean=word(fname,1)
	drop if fname=="" | strpos(fname,"?")!=0 | strpos(fname,"(")!=0 | fname==",," | strpos(fname,":")!=0
	drop if strpos(fname,"..")!=0
	drop if strpos(lname,"...")!=0
	drop if strpos(fname,"---")!=0
	drop if strpos(fname,".")==1
	replace lname=subinstr(lname,",","",.)
	replace fname=fnameclean if strpos(word(fname,1), ".")!=0 & wordcount(fname)>1
	gen middleinit=word(fname,2) if length(word(fname,2))==1

gen double pid=_n

replace race=floor(race/10)

replace bpl=floor(bpl/100)
replace fbpl=floor(fbpl/100)
replace mbpl=floor(mbpl/100)
foreach xvar of varlist fname lname age sex serial pernum middleinit pid fbpl mbpl {
	rename `xvar' `xvar'_gen31880
}

compress

save "1880namestdmulti.dta", replace
*/

/*Clean the 1910 census file prior to linking.*/

use age namefrst namelast sex serial pernum yob bpl race pid fbpl mbpl ///
	if sex==1 & age>=27 & age<=47 using "/disk/bulkw/zachward/cens1930.work/1910census/1910natives.dta", clear

rename namefrst fname
rename namelast lname

replace fname=upper(fname)

	replace fname=upper(fname)
	gen fnameclean=word(fname,1)
	drop if fname=="" | strpos(fname,"?")!=0 | strpos(fname,"(")!=0 | fname==",," | strpos(fname,":")!=0
	drop if strpos(fname,"..")!=0
	drop if strpos(lname,"...")!=0
	drop if strpos(fname,"---")!=0
	drop if strpos(fname,".")==1
	replace lname=subinstr(lname,",","",.)
	replace fname=fnameclean if strpos(word(fname,1), ".")!=0 & wordcount(fname)>1
	gen middleinit=word(fname,2) if length(word(fname,2))==1

replace race=floor(race/100)


foreach xvar of varlist fname lname age sex serial pernum middleinit pid fbpl mbpl {
	rename `xvar' `xvar'_gen31910
}

gen slice=floor(uniform()*10)+1	


save "1910namestdmulti.dta", replace


set more off, perm

/********LINKING******/

foreach j in 1 2 4 5 6 8 9 10 11 12 15 16 18 19 20 21 22 23 24 25 26 27 28 30 31 32 33 34 35 ///
	37 38 40 41 44 45 46 47 49 50 51 53 54 55 56{


use "1910namestdmulti.dta", clear

	keep if bpl==`j'
	duplicates tag fname_gen31910 lname_gen31910 race bpl yob , gen(dupname)
	drop if dupname>0
		gen fstart=substr(fname_gen31910,1,1)
		gen lstart=substr(lname_gen31910,1,1)

	save "1910adultspre`j'.dta", replace

	use "1880namestdmulti.dta", clear
	
	keep if bpl==`j'
	duplicates tag fname_gen31880 lname_gen31880 race bpl yob, gen(dupname)
	drop if dupname>0
		gen fstart=substr(fname_gen31880,1,1)
		gen lstart=substr(lname_gen31880,1,1)
	
	save "1880multipreconnectson`j'.dta", replace

	use 1910adultspre`j'.dta, clear

	joinby fstart lstart yob race bpl using 1880multipreconnectson`j'.dta
	gen yobdiff=0
	capture jarowinkler fname_gen31880 fname_gen31910, gen(fdist)
	capture keep if fdist>=.8 & fdist!=.

	capture jarowinkler lname_gen31880 lname_gen31910, gen(ldist)
	capture keep if ldist>=.8 & ldist!=.

	save joinexact`j'.dta, replace

	forvalues i=1(1)3{
		use 1910adultspre`j'.dta, clear

		replace yob=yob+`i'
		joinby fstart lstart yob race bpl using 1880multipreconnectson`j'.dta
		gen yobdiff=`i'
		capture jarowinkler fname_gen31880 fname_gen31910, gen(fdist)
		capture keep if fdist>=.8 & fdist!=.

		capture jarowinkler lname_gen31880 lname_gen31910, gen(ldist)
		capture keep if ldist>=.8 & ldist!=.

		save joinp`i'_`j'.dta, replace
	}

	forvalues i=1(1)3{
		use 1910adultspre`j'.dta, clear
		replace yob=yob-`i'
		joinby fstart lstart yob race bpl using 1880multipreconnectson`j'.dta
		gen yobdiff=`i'

		capture jarowinkler fname_gen31880 fname_gen31910, gen(fdist)
		capture keep if fdist>=.8 & fdist!=.

		capture jarowinkler lname_gen31880 lname_gen31910, gen(ldist)
		capture keep if ldist>=.8 & ldist!=.

		save joinm`i'_`j'.dta, replace
	}

use joinexact`j'.dta, clear

forvalues i=1(1)3{
	append using joinm`i'_`j'.dta
	append using joinp`i'_`j'.dta
}

rename fname_gen31910 namefrst_gen31910
rename lname_gen31910 namelast_gen31910
rename fname_gen31880 namefrst_gen31880
rename lname_gen31880 namelast_gen31880

duplicates drop pid_gen31910 pid_gen31880, force 
	
saveold "predrop19101940linkFB_`j'.dta", replace
}

set more off, perm
cd "/disk/bulkw/zachward/cens1930.work/1880linkforward/"

foreach j in 13 17 29 36 39 42 48{

forvalues slice=1(1)10{

	use if bpl==`j' & slice==`slice' using "1910namestdmulti.dta", clear

	duplicates tag fname_gen31910 lname_gen31910 race bpl yob , gen(dupname)
	drop if dupname>0
	gen fstart=substr(fname_gen31910,1,1)
	gen lstart=substr(lname_gen31910,1,1)
	save "1910adultspre`j'_`slice'.dta", replace

	use "1880namestdmulti.dta", clear
	
	keep if bpl==`j'
	duplicates tag fname_gen31880 lname_gen31880 race bpl yob, gen(dupname)
	drop if dupname>0
	gen fstart=substr(fname_gen31880,1,1)
	gen lstart=substr(lname_gen31880,1,1)
	keep if age<=14

	save "1880multipreconnectson`j'.dta", replace

	use 1910adultspre`j'_`slice'.dta, clear

	joinby fstart lstart yob race bpl using 1880multipreconnectson`j'.dta
	gen yobdiff=0
	capture jarowinkler fname_gen31880 fname_gen31910, gen(fdist)
	capture keep if fdist>=.8 & fdist!=.

	capture jarowinkler lname_gen31880 lname_gen31910, gen(ldist)
	capture keep if ldist>=.8 & ldist!=.

	save joinexact`j'_`slice'.dta, replace

	forvalues i=1(1)3{
		use 1910adultspre`j'_`slice'.dta, clear

		replace yob=yob+`i'
		joinby fstart lstart yob race bpl using 1880multipreconnectson`j'.dta
		gen yobdiff=`i'
		capture jarowinkler fname_gen31880 fname_gen31910, gen(fdist)
		capture keep if fdist>=.8 & fdist!=.

		capture jarowinkler lname_gen31880 lname_gen31910, gen(ldist)
		capture keep if ldist>=.8 & ldist!=.
		save joinp`i'_`j'_`slice'.dta, replace
	}

	forvalues i=1(1)3{
		use 1910adultspre`j'_`slice'.dta, clear
		replace yob=yob-`i'
		joinby fstart lstart yob race bpl using 1880multipreconnectson`j'.dta
		gen yobdiff=`i'
		capture jarowinkler fname_gen31880 fname_gen31910, gen(fdist)
		capture keep if fdist>=.8 & fdist!=.

		capture jarowinkler lname_gen31880 lname_gen31910, gen(ldist)
		capture keep if ldist>=.8 & ldist!=.
		save joinm`i'_`j'_`slice'.dta, replace
	}

use joinexact`j'_`slice'.dta, clear

	forvalues i=1(1)3{
		append using joinm`i'_`j'_`slice'.dta
		append using joinp`i'_`j'_`slice'.dta
	}

	rename fname_gen31910 namefrst_gen31910
	rename lname_gen31910 namelast_gen31910
	rename fname_gen31880 namefrst_gen31880
	rename lname_gen31880 namelast_gen31880

	duplicates drop pid_gen31910 pid_gen31880, force 
	
saveold "predrop18801910linkFB_`j'_`slice'.dta", replace
}
}
