/*This file links the 1910 and 1920 censuses, which is used to acquire a
second observation of the G2 father*/

clear
set more off

cd "/disk/bulkw/zachward/cens1930.work/19101920link/"

use if age>=10 & age<=40 & sex==1 & bpl<=56 "/disk/bulkw/zachward/cens1930.work/1910census/1910natives.dta", clear

gen ind=1
egen totalorig=total(ind)

rename namefrst fullnamefrst
gen middleinit=word(fullnamefrst,2) if length(word(fullnamefrst,2))==1

gen namefrst=word(fullnamefrst,1)

save prelink1910.dta, replace	

	gen yoborig=yob

foreach xvar of varlist _all{
	rename `xvar' `xvar'1910
}

rename yob1910 yob
rename bpl1910 bpl
rename race1910 race
keep serial* pernum* statefip yob* bpl mbpl fbpl race* name* totalorig1910
gen slice=floor(uniform()*100)

save 1910temp.dta, replace

/*Create 1920 Census to connect with*/

use if age>=17 & age<=53 & sex==1 & bpl<=56 using "/disk/bulkw/zachward/cens1930.work/1920census/1920natives.dta", clear

gen ind=1
egen totalorig=total(ind)

rename namefrst fullnamefrst
gen middleinit=word(fullnamefrst,2) if length(word(fullnamefrst,2))==1

gen namefrst=word(fullnamefrst,1)

save prelink1920.dta, replace

	gen yoborig=yob

	
	
foreach xvar of varlist _all{
	rename `xvar' `xvar'1920
}

rename yob1920 yob
rename bpl1920 bpl
rename race1920 race
keep serial* pernum* statefip yob* bpl mbpl fbpl race* name* totalorig1920

save 1920temp.dta, replace


/*Link the small states*/
foreach j in 1 2 4 5 6 8 9 10 11 12 15 16 18 19 20 21 22 ///
	23 24 25 26 27 28 30 31 32 33 34 35 ///
	37 38 40 41 44 45 46 47 49 50 51 53 54 55 56{

	use 1910temp.dta, clear

	drop if namefrst=="" | namelast==""
	keep if bpl==`j'
	duplicates tag namefrst1910 namelast1910 race bpl yob , gen(dupname)
	drop if dupname>0
	gen fstart=substr(namefrst1910,1,1)
	gen lstart=substr(namelast1910,1,1)
		
	save "1910pre`j'.dta", replace

	use 1920temp.dta, clear
	drop if namefrst=="" | namelast==""
	keep if bpl==`j'

	duplicates tag namefrst1920 namelast1920 race bpl yob, gen(dupname)
	drop if dupname>0

	gen fstart=substr(namefrst1920,1,1)
	gen lstart=substr(namelast1920,1,1)

	save "1920pre`j'.dta", replace

	use 1910pre`j'.dta, clear

	joinby fstart lstart yob race bpl using 1920pre`j'.dta
	gen yobdiff=0
	capture jarowinkler namefrst1920 namefrst1910, gen(fdist)
	capture keep if fdist>=.8 & fdist!=.

	capture jarowinkler namelast1920 namelast1910, gen(ldist)
	capture keep if ldist>=.8 & ldist!=.

	save joinexact`j'.dta, replace

	forvalues i=1(1)3{
		use 1910pre`j'.dta, clear
		replace yob=yob+`i'
		joinby fstart lstart yob race bpl using 1920pre`j'.dta
		gen yobdiff=`i'
		capture jarowinkler namefrst1920 namefrst1910, gen(fdist)
		capture keep if fdist>=.8 & fdist!=.

		capture jarowinkler namelast1920 namelast1910, gen(ldist)
		capture keep if ldist>=.8 & ldist!=.


		save joinp`i'_`j'.dta, replace
	}

	forvalues i=1(1)3{
		use 1910pre`j'.dta, clear
		replace yob=yob-`i'
		joinby fstart lstart yob race bpl using 1920pre`j'.dta
		gen yobdiff=`i'
		*keep if _merge==3
		capture jarowinkler namefrst1920 namefrst1910, gen(fdist)
		capture keep if fdist>=.8 & fdist!=.

		capture jarowinkler namelast1920 namelast1910, gen(ldist)
		capture keep if ldist>=.8 & ldist!=.

		save joinm`i'_`j'.dta, replace
	}

	use joinexact`j'.dta, clear

	forvalues i=1(1)3{
		append using joinm`i'_`j'.dta
		append using joinp`i'_`j'.dta
	}


duplicates drop serial1910 pernum1910 serial1920 pernum1920, force 

compress	
saveold "predrop19101920linkFB_`j'.dta", replace
}


/********Split the bit states into 10 subsections and link each subsection*********/
foreach j in 13 17 29 36 39 42 48{

	forvalues slice=0(1)9{

	use 1910temp.dta, clear


	keep if bpl==`j'
	duplicates tag namefrst1910 namelast1910 race bpl yob, gen(dupname)
	drop if dupname>0
		gen fstart=substr(namefrst1910,1,1)
		gen lstart=substr(namelast1910,1,1)
	keep if floor(slice/10)==`slice'	
	save "1910pre`j'_`slice'.dta", replace

	use 1920temp.dta, clear

	keep if bpl==`j'

	duplicates tag namefrst1920 namelast1920 race bpl yob, gen(dupname)
	drop if dupname>0
		gen fstart=substr(namefrst1920,1,1)
		gen lstart=substr(namelast1920,1,1)

	save "1920pre`j'.dta", replace

	use 1910pre`j'_`slice'.dta, clear

	joinby fstart lstart yob race bpl using 1920pre`j'.dta
	gen yobdiff=0
	capture jarowinkler namefrst1920 namefrst1910, gen(fdist)
	capture keep if fdist>=.8 & fdist!=.

	capture jarowinkler namelast1920 namelast1910, gen(ldist)
	capture keep if ldist>=.8 & ldist!=.

	save joinexact`j'_`slice'.dta, replace

	forvalues i=1(1)3{
		use 1910pre`j'_`slice'.dta, clear

		replace yob=yob+`i'
		joinby fstart lstart yob race bpl using 1920pre`j'.dta
		gen yobdiff=`i'
		capture jarowinkler namefrst1920 namefrst1910, gen(fdist)
		capture keep if fdist>=.8 & fdist!=.

		capture jarowinkler namelast1920 namelast1910, gen(ldist)
		capture keep if ldist>=.8 & ldist!=.


		save joinp`i'_`j'_`slice'.dta, replace
	}

	forvalues i=1(1)3{
		use 1910pre`j'_`slice'.dta, clear
		replace yob=yob-`i'
		joinby fstart lstart yob race bpl using 1920pre`j'.dta
		gen yobdiff=`i'
		*keep if _merge==3
		capture jarowinkler namefrst1920 namefrst1910, gen(fdist)
		capture keep if fdist>=.8 & fdist!=.

		capture jarowinkler namelast1920 namelast1910, gen(ldist)
		capture keep if ldist>=.8 & ldist!=.

		save joinm`i'_`j'_`slice'.dta, replace
	}

	use joinexact`j'_`slice'.dta, clear

	forvalues i=1(1)3{
	append using joinm`i'_`j'_`slice'.dta
	append using joinp`i'_`j'_`slice'.dta
	}

	duplicates drop serial1910 pernum1910 serial1920 pernum1920, force 

	compress	
	saveold "predrop19101920linkFB_`j'_`slice'.dta", replace
	}
}

