/*This file builds the set of potential links between 1910 and 1940 census
based on the Feigenbaum (2016) method. */

set more off
cd "/disk/bulkw/zachward/cens1930.work/1910census/"

/*First, pre-clean the 1910 census. 
1910natives.dta is the full-count census file*/

use namefrst namelast age sex serial pernum yob bpl race pid if age<=14 & sex==1 using "1910natives.dta", clear

/*Clean names*/
	rename namefrst fname
	rename namelast lname
	replace fname=upper(fname)
	gen fnameclean=word(fname,1)
	drop if fname=="" | strpos(fname,"?")!=0 | strpos(fname,"(")!=0 | fnameclean==",," | strpos(fname,":")!=0
	drop if strpos(fname,"..")!=0
	drop if strpos(lname,"...")!=0
	drop if strpos(fname,"---")!=0
	drop if strpos(fname,".")==1
	replace lname=subinstr(lname,",","",.)
	replace fname=fnameclean if strpos(word(fname,1), ".")!=0 & wordcount(fname)>1
	gen middleinit=word(fname,2) if length(word(fname,2))==1

replace race=floor(race/100)
gen ind=1


foreach xvar of varlist fname lname age sex serial pernum middleinit pid {
	rename `xvar' `xvar'_gen41910
}

compress

save "1910namestdmulti.dta", replace


/*Clean the 1940 census file prior to linking.*/

use age sex bpl race serialp pernum namefrst namelast if sex==1 & age>=27 & age<=47 ///
	using "/disk/bulkw/zachward/cens1940.work/1940census/1940fullcountmultilink.dta", clear

	rename namefrst fname
	rename namelast lname
	replace fname=upper(fname)
	gen fnameclean=word(fname,1)
	drop if fname=="" | strpos(fname,"?")!=0 | strpos(fname,"(")!=0 | fnameclean==",," | strpos(fname,":")!=0
	drop if strpos(fname,"..")!=0
	drop if strpos(lname,"...")!=0
	drop if strpos(fname,"---")!=0
	drop if strpos(fname,".")==1
	replace lname=subinstr(lname,",","",.)
	replace fname=fnameclean if strpos(word(fname,1), ".")!=0 & wordcount(fname)>1
	gen middleinit=word(fname,2) if length(word(fname,2))==1

	
foreach xvar of varlist fname lname age sex middleinit serial pernum {
	rename `xvar' `xvar'_gen41940
}
gen year=1940
replace race=floor(race/100)
replace race=4 if race==5

/*Create unique ID for the 1940 census*/
rename serialp serial
egen double pid_gen41940=group(serial pernum)

/*Split data into smaller pieces for linking larger states*/
gen slice=floor(uniform()*10)+1	

compress

save "1940adultsstd.dta", replace

/*Creating set of potential links between 1910 and 1940.

Split into small states and big states since Stata cannot handle the 
pairwise combination of links for big states.*/

foreach j in 1 2 4 5 6 8 9 10 11 12 15 16 18 19 20 21 22 ///
	23 24 25 26 27 28 30 31 32 33 34 35 ///
	37 38 40 41 44 45 46 47 49 50 51 53 54 55 56{

	use "1940adultsstd.dta", clear

	gen yob=1940-age

	keep if bpl==`j'
	duplicates tag fname_gen41940 lname_gen41940 race bpl yob , gen(dupname)
	drop if dupname>0
		gen fstart=substr(fname_gen41940,1,1)
		gen lstart=substr(lname_gen41940,1,1)

		keep if age>=27 & age<=47
		
	save "1940adultspre`j'.dta", replace

	use "1910namestdmulti.dta", clear
	*gen yob=1910-age

	keep if bpl==`j'
	duplicates tag fname_gen41910 lname_gen41910 race bpl yob, gen(dupname)
	drop if dupname>0
		gen fstart=substr(fname_gen41910,1,1)
		gen lstart=substr(lname_gen41910,1,1)
		keep if age<=14

	save "1910multipreconnectson`j'.dta", replace

	use 1940adultspre`j'.dta, clear

	joinby fstart lstart yob race bpl using 1910multipreconnectson`j'.dta
	gen yobdiff=0
	capture jarowinkler fname_gen41910 fname_gen41940, gen(fdist)
	capture keep if fdist>=.8 & fdist!=.

	capture jarowinkler lname_gen41910 lname_gen41940, gen(ldist)
	capture keep if ldist>=.8 & ldist!=.

	save joinexact`j'.dta, replace

	forvalues i=1(1)3{
		use 1940adultspre`j'.dta, clear

		replace yob=yob+`i'
		joinby fstart lstart yob race bpl using 1910multipreconnectson`j'.dta
		gen yobdiff=`i'
		
		capture jarowinkler fname_gen41910 fname_gen41940, gen(fdist)
		capture keep if fdist>=.8 & fdist!=.

		capture jarowinkler lname_gen41910 lname_gen41940, gen(ldist)
		capture keep if ldist>=.8 & ldist!=.

		save joinp`i'_`j'.dta, replace
	}

	forvalues i=1(1)3{
		use 1940adultspre`j'.dta, clear
		replace yob=yob-`i'
		joinby fstart lstart yob race bpl using 1910multipreconnectson`j'.dta
		gen yobdiff=`i'

		capture jarowinkler fname_gen41910 fname_gen41940, gen(fdist)
		capture keep if fdist>=.8 & fdist!=.

		capture jarowinkler lname_gen41910 lname_gen41940, gen(ldist)
		capture keep if ldist>=.8 & ldist!=.

		save joinm`i'_`j'.dta, replace
	}

	use joinexact`j'.dta, clear

	forvalues i=1(1)3{
		append using joinm`i'_`j'.dta
		append using joinp`i'_`j'.dta
	}

	rename fname_gen41940 namefrst_gen41940
	rename lname_gen41940 namelast_gen41940
	rename fname_gen41910 namefrst_gen41910
	rename lname_gen41910 namelast_gen41910

	duplicates drop pid_gen41940 pid_gen41910, force 
	saveold "predrop19101940linkFB_`j'.dta", replace
}

/* Big states. The dataset is split into 10 "slices" and I link each slice.*/

foreach j in 13 17 29 36 39 42 48{
	forvalues slice=1(1)10{
	set more off, perm

	use if bpl==`j' & slice==`slice' using "1940adultsstd.dta", clear
	gen yob=1940-age
	duplicates tag fname_gen41940 lname_gen41940 race bpl yob , gen(dupname)
	drop if dupname>0
	
	gen fstart=substr(fname_gen41940,1,1)
	gen lstart=substr(lname_gen41940,1,1)
		
	save "1940adultspre`j'_`slice'.dta", replace

	use if bpl==`j' using "1910namestdmulti.dta", clear
	
	duplicates tag fname_gen41910 lname_gen41910 race bpl yob, gen(dupname)
	drop if dupname>0

	gen fstart=substr(fname_gen41910,1,1)
	gen lstart=substr(lname_gen41910,1,1)

	save "1910multipreconnectson`j'.dta", replace

	use 1940adultspre`j'_`slice'.dta, clear

	joinby fstart lstart yob race bpl using 1910multipreconnectson`j'.dta
	gen yobdiff=0
	capture jarowinkler fname_gen41910 fname_gen41940, gen(fdist)
	capture keep if fdist>=.8 & fdist!=.

	capture jarowinkler lname_gen41910 lname_gen41940, gen(ldist)
	capture keep if ldist>=.8 & ldist!=.

	save joinexact`j'_`slice'.dta, replace

	forvalues i=1(1)3{
		use 1940adultspre`j'_`slice'.dta, clear

		replace yob=yob+`i'
		joinby fstart lstart yob race bpl using 1910multipreconnectson`j'.dta
		gen yobdiff=`i'
		capture jarowinkler fname_gen41910 fname_gen41940, gen(fdist)
		capture keep if fdist>=.8 & fdist!=.

		capture jarowinkler lname_gen41910 lname_gen41940, gen(ldist)
		capture keep if ldist>=.8 & ldist!=.


		save joinp`i'_`j'_`slice'.dta, replace
	}

	forvalues i=1(1)3{
		use 1940adultspre`j'_`slice'.dta, clear
		replace yob=yob-`i'
		joinby fstart lstart yob race bpl using 1910multipreconnectson`j'.dta
		gen yobdiff=`i'
		capture jarowinkler fname_gen41910 fname_gen41940, gen(fdist)
		capture keep if fdist>=.8 & fdist!=.

		capture jarowinkler lname_gen41910 lname_gen41940, gen(ldist)
		capture keep if ldist>=.8 & ldist!=.

		save joinm`i'_`j'_`slice'.dta, replace
	}
	
	use joinexact`j'_`slice'.dta, clear

	forvalues i=1(1)3{
		append using joinm`i'_`j'_`slice'.dta
		append using joinp`i'_`j'_`slice'.dta
	}

	rename fname_gen41940 namefrst_gen41940
	rename lname_gen41940 namelast_gen41940
	rename fname_gen41910 namefrst_gen41910
	rename lname_gen41910 namelast_gen41910

	duplicates drop pid_gen41940 pid_gen41910, force 
		
	saveold "predrop19101940linkFB_`j'_`slice'.dta", replace
	}
}
