/*Intergenerational analysis*/

set more off, perm

cd "/disk/bulkw/zachward/cens1930.work/ImmigrantMulti/"

*****************************************************************

/* This file sets up the 3-generation link for analysis*/

use "data/188019101940_G3_G2_G1.dta", clear

/*Consistent country coding*/
replace bpl_G11880=465 if bpl_G11880==455 | bpl_G11880==460 | bpl_G11880==461 | bpl_G11880==462
replace bpl_G11880=450 if bpl_G11880==454 | bpl_G11880==452 | bpl_G11880==457
replace bpl_G11880=410 if bpl_G11880==413 | bpl_G11880==412

/*Attach local ethnicity averages for 
1) 1880 and 2) 1910*/
rename statefip_G11880 statefip
rename county_G11880 county

/*First for 1880, attached 1) enumeration district, 2) county, 3)national*/
rename statefip statefip_G11880
rename county county_G11880

merge m:1 bpl_G11880 statefip_G11880 county_G11880 enumdist_G11880 using "data/ethniccapitalenumeration1880.dta"
drop if _merge==2
drop _merge

merge m:1 bpl_G11880 statefip_G11880 county_G11880 using "data/ethniccapitalcounty1880.dta"
drop if _merge==2
drop _merge

rename fbpl fbpl_G21910
rename mbpl mbpl_G21910

merge m:1 bpl_G11880 statefip_G21910 county_G21910 enumdist_G21910 using "data/ethniccapitalenumeration1910.dta"
drop if _merge==2
drop _merge

merge m:1 bpl_G11880 statefip_G21910 county_G21910 using "data/ethniccapitalcounty1910.dta"
drop if _merge==2
drop _merge


drop region_G11880

foreach xvar in _G11880 _G21910 _G31940{

	rename occ1950`xvar' occ1950
	rename statefip`xvar' statefip

	/*1950 occupational score and 1890 Sobek score*/
	
	merge m:1 occ1950 using "data/occscore.dta"
	drop if _merge==2
	drop _merge

	/*Use the Farmer income estimates by state from Ager, Boustan and Eriksson 
	for the 1880 Census.*/
	merge m:1 statefip using "data/farmer_income_estimates_1880.dta"
	drop if _merge==2
	drop _merge

	merge m:1 statefip using "data/region.dta", update
	drop if _merge==2
	replace region=42 if region==.
	drop _merge

	rename region regiond
	gen region=floor(regiond/10)
	*gen region=regiond
	
	gen group=1

	merge m:1 group occ1950 region using "data/cwscore_native_multgen.dta"
	drop if _merge==2
	drop _merge

	gen occ1950_1=floor(occ1950/100)
	merge m:1 group occ1950_1 region using "data/cwscore_native_multgen_1.dta"
	drop if _merge==2
	drop _merge

	replace cwscore_group=incwagemean_1 if cwscore_group==.

	merge m:1 occ1950 statefip using "data/farmer_adj.dta"
	drop if _merge==2
	drop _merge


	rename farmer_income_V1 farmer_income_V1`xvar'
	rename annearn_flabor80 annearn_flabor80`xvar'
	rename cwscore_group cwscore`xvar'
	rename occ1950 occ1950`xvar'
	rename occ1950_1 occ1950_1`xvar'
	rename statefip statefip`xvar'
	rename region region`xvar'
	rename regiond regiond`xvar'
	rename group group`xvar'
	rename sobekscore sobekscore`xvar'
	rename sobekscore_pred sobekscore_pred`xvar'
	rename cls1901 cls1901`xvar'
	rename cls1901_pred cls1901_pred`xvar'
	rename ratio ratio`xvar'

	/*Main score used 1901 CLS for 1880 and 1910 for non farmers,
	1880, 1900 ag census for farmers
	Holmes and Young for farmer laborers,
	county adjustment from 1940 census for farmers
	occupational score for non farmers

	Adjust income to 2015 dollars - Measuring worth CPI
	1880 to 2015 - 237.02/9.91
	1900 to 2015 - 237.02/8.14
	1910 to 2015 - 237.02/9.21
	1940 (1939 income) to 2015 - 237.02/13.89
	1950 to 2015 - 237.02/24.08

	*/

	*drop if occ1950>970	

	/*Fill in missing occupations from the Cost of Living Score based on distribution
	of occupation in the 1950 score*/

	gen loccscore1880`xvar'=log(cls1901`xvar'*237.02/8.24) 
		replace loccscore1880`xvar'=log(farmer_income_V1`xvar'*237.02/9.91) if occ1950`xvar'==100
		replace loccscore1880`xvar'=log(annearn_flabor80`xvar'*237.02/9.91) if occ1950`xvar'==820

	/*Occupational Score from Sobek (1996)*/	
	gen lsobekscore`xvar'=log(sobekscore_pred`xvar'*237.02/8.82)
		
	/*Simple Occupation Score from 1950*/
	gen loccscore`xvar'=log(occscore`xvar'*237.02/24.08*100)

	/*Simple Occupation Score from 1950*/
	gen loccscore_adj`xvar'=log(occscore`xvar'*237.02/24.08*100)
		replace loccscore_adj`xvar'=log(occscore`xvar'*237.02/24.08*100*ratio`xvar') if occ1950`xvar'==100 | occ1950`xvar'==820


	/*Occupational score from 1939*/
	gen lcwscore`xvar'=log(cwscore`xvar'*237.02/13.89)

	gen lcls`xvar'=log(cls1901_pred`xvar'*237.02/8.24)

	gen wc`xvar'=(floor(occ1950`xvar'/100)==0 | floor(occ1950`xvar'/100)==2 ///
		| floor(occ1950`xvar'/100)==3 |floor(occ1950`xvar'/100)==4) if occ1950`xvar'!=.
		
	gen prof`xvar'=(floor(occ1950`xvar'/100)==0 | floor(occ1950`xvar'/100)==2) ///
		 if occ1950`xvar'!=.
		
	gen sales`xvar'= (floor(occ1950`xvar'/100)==3 |floor(occ1950`xvar'/100)==4) if occ1950`xvar'!=.
		
	gen servicelow`xvar'=(floor(occ1950`xvar'/100)==7) if occ1950`xvar'!=.
		
	gen oper`xvar'=(floor(occ1950`xvar'/100)== 6) if occ1950`xvar'!=.
		
	gen lab`xvar'=(floor(occ1950`xvar'/100)==8 | floor(occ1950`xvar'/100)==9) & occ1950`xvar'<=970
		
	gen farmer`xvar'=(floor(occ1950`xvar'/100)==1) if occ1950`xvar'!=.

	gen unskilled`xvar'=(floor(occ1950`xvar'/100)==8 | ///
		floor(occ1950`xvar'/100)==9 |floor(occ1950`xvar'/100)==7 | ///
		floor(occ1950`xvar'/100)==6) & occ1950`xvar'<=970 if occ1950`xvar'!=.

	gen skilled`xvar'=(floor(occ1950`xvar'/100)==5) if occ1950`xvar'!=.

	capture gen literate`xvar'=lit`xvar'==4 if lit`xvar'!=0

}

gen farmer=(occ1950_G11880==100 | occ1950_G21910==100 | occ1950_G31940==100)

foreach xvar in _G11880 _G21910 _G31940{
	gen age40`xvar'=age`xvar'-40
	gen age40sq`xvar'=(age`xvar'-40)^2
	gen age40cub`xvar'=(age`xvar'-40)^3
	gen age40quad`xvar'=(age`xvar'-40)^4

}


drop if bpl_G11880<100 
drop if bpl_G21910>100
drop if bpl_G31940>100 
drop if occ1950_G11880>970 
drop if occ1950_G21910>970 
drop if occ1950_G31940>970 

/*Ensure regression sample is fixed*/
reg wc_G31940 c.wc_G11880##c.age40*G3* c.wc_G21910##c.age40*G3* c.age40_G2* c.age40_G1* wcbarED1 wcbarED2 , cluster(serial_G21880)
drop if e(sample)==0

/*Education and wage data*/

recode educ_G31940 (2=0) (12=0) (14=1) (15=2) (16=3) (17=4) (22=5) (23=6) (25=7) ///
	(26=8) (30=9) (40=10) (50=11) (60=12) (70=13) (80=14) (90=15) (100=16) ///
	(110=18), gen(educyears_G31940)
replace educyears_G31940=. if educyears_G31940==999


gen incwagecorrected=incwage_G31940
replace incwagecorrected=. if floor(classwkr_G31940/10)!=2
replace incwagecorrected=. if incwage_G31940>999997
replace incwagecorrected=5000 if incwage_G31940>5000 & incwage_G31940!=.
replace incwagecorrected=5000*1.4 if incwage_G31940>=5000 & incwage_G31940!=.

gen lincwage=log(incwagecorrected)

sort serial_G31910 pernum_G21910
by serial_G31910 pernum_G21910: gen num=_n

sort serial_G21880 pernum_G11880
by serial_G21880 pernum_G11880: gen num2=_n



save "builddata/188019101940temp.dta", replace /*Use this file to for weighting, then re-run the analysis.*/
