/*Weight the 1880-1910-1940 data*/

set more off, perm

cd "/disk/bulkw/zachward/cens1930.work/ImmigrantMulti/"

/*This files reweights the 1880-1910-1940 linked sample to be representative on 
observables.

The process is as follows:
1) First weight G2 in 1880 to be representative of sons in 1880
2) Second, use these weights for G3 in 1910 to be representative of sons in 1910

*/

use "builddata/188019101940temp.dta", clear

*gen G1indiv=(num==1)
*egen totalG1indiv=total(G1indiv), by(bpl_G11880)
*drop if totalG1indiv<30 | bpl_G11880==260


/*Keep only one observation of the G2 father in 1880*/ 
duplicates drop serial_G21880 pernum_G21880, force


/**************************************************************************/
				
/*First we will weight G1 w/r/t fathers in the 1880 census*/
				
/*Desciptives*/
	keep bpl* occ* statefip* age* lit* race* mbpl* fbpl* serial_G21880 pernum_G21880 serial_G31940 pernum_G31940
	gen linked=1
	append using "data/1880representativeforlink.dta"
	replace linked=0 if linked==.
	drop if bpl_pop<100
	
/*Create consistent coding between 1880 representative and 1880 linked*/	
	foreach xvar in age bpl occ1950 mbpl fbpl{
	replace `xvar'_pop=`xvar'_G11880 if `xvar'==.
	}

/*Keep age range of parents the same*/
	drop if age_pop<30 | age_pop>55
	drop if occ1950_pop>970
	rename occ1950 occ1950_son
	rename occ1950_pop occ1950
	drop occscore occscore_pop

	replace statefip=statefip_G11880 if linked==1

	merge m:1 statefip using "data/region.dta", update
	drop if _merge==2
	replace region=42 if region==.
	drop _merge

	merge m:1 occ1950 using "data/abecol.dta", keepusing(cls1901)
	drop if _merge==2
	drop _merge

	gen group=.
	replace group=1 if race==1 | race==10 | race==100
	replace group=2 if race==2 | floor(race/10)==2
	replace group=3 if bpl==200 | fbpl==200 | mbpl==200
	replace group=4 if group==.

	merge m:1 statefip using "data/region.dta", update
	drop if _merge==2
	replace region=42 if region==.
	drop _merge

	merge m:1 occ1950 using "data/occscore", update
	drop if _merge==1
	drop _merge


	/*Main score used 1901 CLS for 1880 and 1910 for non farmers,
	1880, 1900 ag census for farmers
	Holmes and Young for farmer laborers,
	county adjustment from 1940 census for farmers
	occupational score for non farmers

	Adjust income to 2015 dollars - Measuring worth CPI
	1880 to 2015 - 237.02/9.91
	1900 to 2015 - 237.02/8.14
	1910 to 2015 - 237.02/9.21
	1940 (1939 income) to 2015 - 237.02/13.89
	1950 to 2015 - 237.02/24.08

	*/

	drop if occ1950>970

	/*Fill in missing occupations from the Cost of Living Score based on distribution
	of occupation in the 1950 score*/

	gen lsobekscore=log(sobekscore_pred*237.02/8.82)
	
	/*Simple Occupation Score from 1950*/
	gen loccscore=log(occscore*237.02/24.08*100)

	/*Recode the WC, Farmer Unskilled and Skilled categories to be consistent*/
	gen wc=(floor(occ1950/100)==0 | floor(occ1950/100)==2 | ///
	floor(occ1950/100)==3 |floor(occ1950/100)==4) if occ1950!=.

	gen farmer=(floor(occ1950/100)==1) if occ1950!=.

	gen unskilled=(floor(occ1950/100)==8 | ///
	floor(occ1950/100)==9 |floor(occ1950/100)==7 | ///
	floor(occ1950/100)==6) & occ1950<=970 if occ1950!=.

	gen skilled=(floor(occ1950/100)==5) if occ1950!=.

	gen ne=(region==11 | region==12)
	gen mw=(region==21 | region==22)
	gen south=(region==31 | region==32 | region==33)
	gen west=(region==41 | region==42)

	replace bpl_pop=465 if bpl_pop==455 | bpl_pop==460 | bpl_pop==461 | bpl_pop==462
	replace bpl_pop=450 if bpl_pop==454 | bpl_pop==452 | bpl_pop==457
	replace bpl_pop=410 if bpl_pop==413 | bpl_pop==412


	gen canada=bpl_pop==150
	gen germany=bpl_pop==453
	gen ireland=bpl_pop==414
	gen england=bpl_pop==410
	gen france=bpl_pop==421
	gen netherlands=bpl_pop==425
	gen swiss=bpl_pop==426
	gen russia=bpl_pop==465
	gen austria=bpl_pop==450
	gen norway=bpl_pop==404
	gen sweden=bpl_pop==405
	gen scotland=bpl_pop==411
	gen italy=bpl_pop==434

	gen y=uniform()

	replace age=age_G21880 if linked==1

	reg y age age_pop wc unskilled skilled farmer ne mw south west loccscore  lsobekscore ///
	germany ireland england canada france netherlands swiss russia austria norway sweden ///
	scotland italy if linked==1
	outreg2 using "tables/1880rep", excel replace sum

	reg y age age_pop wc unskilled skilled farmer ne mw south west loccscore lsobekscore ///
	germany ireland england canada france netherlands swiss russia austria norway sweden ///
	scotland italy if linked==0
	outreg2 using "tables/1880rep", excel append sum

		
	/********weighting******/
	save "temprep.dta", replace
		
	matrix drop _all
	
	gen ind=1
	
	gen occCat=.
	replace occCat=1 if wc==1
	replace occCat=2 if farmer==1
	replace occCat=3 if unskilled==1
	replace occCat=4 if skilled==1
	replace bpl_pop=1000 if bpl_pop!=150 & bpl_pop!=404 & bpl_pop!=405 ///
		& bpl_pop!=410 & bpl_pop!=411 & bpl_pop!=414 & bpl_pop!=421 ///
		& bpl_pop!=426 & bpl_pop!=450 & bpl_pop!=452 & bpl_pop!=453 & bpl_pop!=455
	
	replace region=floor(region/10)
	
	egen weightgroup=group(region bpl_pop occCat)
	egen totallinkedgroup=total(ind), by(weightgroup linked)
	egen totalgroup=total(ind), by(weightgroup)
	drop if totalgroup-totallinkedgroup==0
	replace ind=. if linked==1
	
	
	total ind, over(weightgroup, nolab)
	matrix totalgroup=e(b)
	matrix rownames totalgroup = weightgroup
	
	keep if linked==1
	replace ind=1
	ipfraking [pw=linked], ctotal(totalgroup)  generate(weight18801910)	
	keep serial_G21880 pernum_G21880 weight18801910
	save "builddata/weight18801910.dta", replace
		
	merge 1:m serial_G21880 pernum_G21880 using temprep.dta
	drop _merge
	replace weight18801910=1 if weight18801910==.
		
	reg y age age_pop wc unskilled skilled farmer ne mw south west loccscore lsobekscore ///
	germany ireland england canada france netherlands swiss russia austria norway sweden ///
	scotland italy [aw=weight18801910] if linked==1
	outreg2 using "tables/1880rep", excel append sum


/**************************************************************************/

/*1880-1910-1940*/

use "builddata/188019101940temp.dta", clear
capture drop weight188019101940
	merge m:1 serial_G21880 pernum_G21880 using "builddata/weight18801910.dta"
	drop _merge
	/*Desciptives*/
	keep bpl* occ* statefip* age* literate* race* mbpl* fbpl* weight serial* pernum*
	gen linked=1
	append using "data/1910representativeforlink.dta"
	replace linked=0 if linked==.

	keep bpl* occ* statefip* age* literate* race* mbpl* fbpl* lit* linked weight serial* pernum*


	foreach xvar in age bpl occ1950 mbpl fbpl race{
	replace `xvar'_pop=`xvar'_G21910 if `xvar'==.
	}

	drop if (age_pop<30 | age_pop>44) & linked==0
	rename occ1950 occ1950_son
	rename occ1950_pop occ1950
	drop occscore

	replace statefip=statefip_G21910 if statefip==.

	merge m:1 statefip using "data/region.dta", update
	drop if _merge==2
	replace region=42 if region==.
	drop _merge

	merge m:1 occ1950 using "data/abecol.dta", keepusing(cls1901)
	drop if _merge==2
	drop _merge

	/*Use the Farmer income estimates by state from Ager, Boustan and Eriksson (2016)
	for the 1880 and 1910 Census.*/
	merge m:1 statefip using "data/farmer_income_estimates_1880.dta"
	drop if _merge==2
	drop _merge

	gen group=.
	replace group=1 if race==1 | race==10 | race==100
	replace group=2 if race==2 | floor(race/10)==2
	replace group=3 if bpl==200 | fbpl==200 | mbpl==200
	replace group=4 if group==.

	merge m:1 statefip using "data/region.dta", update
	drop if _merge==2
	replace region=42 if region==.
	drop _merge



	merge m:1 occ1950 using "data/occscore", update
	drop if _merge==1
	drop _merge


		gen lsobekscore=log(sobekscore_pred*237.02/8.82)
	
	/*Main score used 1901 CLS for 1880 and 1910 for non farmers,
	1880, 1900 ag census for farmers
	Holmes and Young for farmer laborers,
	county adjustment from 1940 census for farmers
	occupational score for non farmers

	Adjust income to 2015 dollars - Measuring worth CPI
	1880 to 2015 - 237.02/9.91
	1900 to 2015 - 237.02/8.14
	1910 to 2015 - 237.02/9.21
	1940 (1939 income) to 2015 - 237.02/13.89
	1950 to 2015 - 237.02/24.08

	*/

	drop if occ1950>970

	/*Simple Occupation Score from 1950*/
	gen loccscore=log(occscore*237.02/24.08*100)

	/*Recode the WC, Farmer Unskilled and Skilled categories to be consistent*/

	gen wc=(floor(occ1950/100)==0 | floor(occ1950/100)==2 | ///
	floor(occ1950/100)==3 |floor(occ1950/100)==4) if occ1950!=.

	gen farmer=(floor(occ1950/100)==1) if occ1950!=.

	gen unskilled=(floor(occ1950/100)==8 | ///
	floor(occ1950/100)==9 |floor(occ1950/100)==7 | ///
	floor(occ1950/100)==6) & occ1950<=970 if occ1950!=.

	gen skilled=(floor(occ1950/100)==5) if occ1950!=.

	gen ne=(region==11 | region==12)
	gen mw=(region==21 | region==22)
	gen south=(region==31 | region==32 | region==33)
	gen west=(region==41 | region==42)
	
	replace fbpl_pop=465 if fbpl_pop==455 | fbpl_pop==460 | fbpl_pop==461 | fbpl_pop==462
	replace fbpl_pop=450 if fbpl_pop==454 | fbpl_pop==452 | fbpl_pop==457
	replace fbpl_pop=410 if fbpl_pop==413 | fbpl_pop==412
	
	gen canada=fbpl_pop==150
	gen germany=fbpl_pop==453
	gen ireland=fbpl_pop==414
	gen england=fbpl_pop==410
	gen france=fbpl_pop==421
	gen netherlands=fbpl_pop==425
	gen swiss=fbpl_pop==426
	gen russia=fbpl_pop==465
	gen austria=fbpl_pop==450
	gen norway=fbpl_pop==404
	gen sweden=fbpl_pop==405
	gen scotland=fbpl_pop==411
	gen italy=fbpl_pop==434


	gen y=uniform()

	replace age=age_G31910 if linked==1

	reg y age age_pop wc unskilled skilled farmer ne mw south west loccscore  lsobekscore ///
	germany ireland england canada france netherlands swiss russia austria norway sweden ///
	scotland italy if linked==1
	outreg2 using "tables/1910rep", excel replace sum

	reg y age age_pop wc unskilled skilled farmer ne mw south west loccscore  lsobekscore ///
	germany ireland england canada france netherlands swiss russia austria norway sweden ///
	scotland italy if linked==0
	outreg2 using "tables/1910rep", excel append sum


		/********weighting******/
	save temprep1910.dta, replace


	matrix drop _all

	
	gen ind=1
	
	gen occCat=.
	replace occCat=1 if wc==1
	replace occCat=2 if farmer==1
	replace occCat=3 if unskilled==1
	replace occCat=4 if skilled==1
	replace fbpl_pop=1000 if fbpl_pop!=150 & fbpl_pop!=404 & fbpl_pop!=405 & fbpl_pop!=410 & ///
		fbpl_pop!=411 & fbpl_pop!=414 & fbpl_pop!=421 & fbpl_pop!=426 & fbpl_pop!=450 & ///
		fbpl_pop!=452 & fbpl_pop!=453 & fbpl_pop!=455
	
	
	replace region=floor(region/10)
	
	egen weightgroup=group(region fbpl_pop occCat)
	egen totallinkedgroup=total(ind), by(weightgroup linked)
	egen totalgroup=total(ind), by(weightgroup)
	drop if totalgroup-totallinkedgroup==0
	replace ind=. if linked==1
	
	total ind, over(weightgroup, nolab)
	matrix totalgroup=e(b)
	matrix rownames totalgroup = weightgroup
	
	keep if linked==1
	replace ind=1
	ipfraking [pw=weight18801910], ctotal(totalgroup)  generate(weight188019101940)	
	keep serial_G31940 pernum_G31940 weight18801910*
	save "data/weight188019101940.dta", replace
		
		
	use "data/weight188019101940.dta", clear
		merge 1:m serial_G31940 pernum_G31940 using temprep1910.dta
	drop _merge
	replace weight188019101940=1 if weight188019101940==.
	
		reg y age age_pop wc unskilled skilled farmer ne mw south west loccscore  lsobekscore ///
		germany ireland england canada france netherlands swiss russia austria norway sweden ///
		scotland italy [aw=weight188019101940] if linked==1
		outreg2 using "tables/1910rep", excel append sum
		
			use "data/weight188019101940.dta", clear
	
	merge 1:m serial_G31940 pernum_G31940 using temprep.dta
	drop _merge
	replace weight188019101940=1 if weight188019101940==.
	
		reg y age age_pop wc unskilled skilled farmer ne mw south west loccscore  lsobekscore ///
		germany ireland england canada france netherlands swiss russia austria norway sweden ///
		scotland italy [aw=weight188019101940] if linked==1
		outreg2 using "tables/1880rep", excel append sum

	erase temprep.dta
	erase temprep1910.dta
