set more off, perm

cd "/disk/bulkw/zachward/cens1930.work/ImmigrantMulti/"

use "builddata/188019101940temp.dta", clear 

merge m:1 serial_G31940 pernum_G31940 using "data/weight188019101940.dta"
keep if _merge==3
drop _merge	

replace loccscore1880_G31940=loccscore_adj_G31940
replace lsobekscore_G31940=loccscore_G31940
gen lclsadj_G31940=log(cls1901_pred_G31940*237.02/8.24*ratio_G31940)


/*Keep only those with greater than 30 observations. Drop West Indies since
the country is unclear*/
gen G1indiv=(num==1)
egen totalG1indiv=total(G1indiv), by(bpl_G11880)
drop if totalG1indiv<30 | bpl_G11880==260

foreach x in _G11880 _G21910 _G31940{
	gen loccscore_nf`x'=loccscore`x' if occ1950`x'!=100
	gen loccsc1880_nf`x'=loccscore1880`x' if occ1950`x'!=100
	gen lcwscore_nf`x'=lcwscore`x' if occ1950`x'!=100
	gen lsobekscore_nf`x'=lsobekscore`x' if occ1950`x'!=100
}	


	

preserve

	foreach xvar in farmer wc prof sales skilled unskilled servicelow lab oper ///
		loccscore literate loccscore1880 lcwscore loccscore_nf loccsc1880_nf ///
		lcwscore_nf lsobekscore lsobekscore_nf {
		replace `xvar'_G21910=. if num>=2
		replace `xvar'_G11880=. if num2>=2
		
	}

	/*Show convergence within dataset*/
	gen indiv=1

	collapse farmer* wc* skilled* unskilled* loccsc* lcwscore* prof* servicelow* ///
		literate* sales* lab* oper* lsobekscore* lcls* (rawsum) rawindiv=G1indiv (sum) indiv [pw=weight188019101940], by(bpl_G11880)

	*drop if rawindiv<30


	rename bpl bpl
	merge 1:1 bpl using "data/bpllabel.dta"
	drop if _merge==2
	drop _merge

	gen position=12
	reg lsobekscore_G31940 lsobekscore_G11880  [pw=indiv]
	predict lres, res
	replace bplstr="RUS" if bplstr=="RUS/POL"

	replace position=6 if lres <0
	replace position=1 if bplstr=="NOR" | bplstr=="NOR"
	replace position=9 if bplstr=="SWZ" | bplstr=="NLD"
	replace position=12 if bplstr=="FRA" | bplstr=="MEX" |bplstr=="BEL" 
	replace position=3 if bplstr=="RUS"
	replace position=10 if bplstr=="CAN"
	replace position=9 if bplstr=="SPA"
	replace position=6 if bplstr=="ITA" | bplstr=="SWE" | bplstr=="ENG"

	twoway (scatter lsobekscore_G31940 lsobekscore_G11880, mlabel(bplstr) mlabvp(position)) ///
		(lfit lsobekscore_G31940 lsobekscore_G11880 [pw=indiv]) ///
		(lfit lsobekscore_G31940 lsobekscore_G11880 if floor(bpl/100)==4 [pw=indiv]) ///
		, ytitle("Log Occupational Income of 3rd gen in 1940") xtitle("Log Occupational Income of 1st gen in 1880") ///
		scheme(s2mono) legend(order(2 "All Sources" 3 "Only Europeans"))	
	graph export "figures/collapsed_lsobek.png", width(10000) replace
		
	capture drop *CLPSD*
	foreach xvar in farmer wc prof sales skilled unskilled servicelow lab oper loccscore loccscore1880 literate lcwscore loccscore_nf loccsc1880_nf lcwscore_nf lsobekscore lsobekscore_nf lcls{
		rename `xvar'_G11880 `xvar'CLPSDbar1
		rename `xvar'_G21910 `xvar'CLPSDbar2
		capture rename `xvar'_G31940 `xvar'CLPSDbar3
	}

	capture erase "tables/ethnicaveraged.xml"
	capture erase "tables/ethnicaveraged.txt"
	capture erase "tables/ethnicaveragedar2.xml"
	capture erase "tables/ethnicaveragedar2.txt"

	foreach xvar in farmer wc skilled unskilled  lsobekscore loccscore {
		reg `xvar'CLPSDbar2 `xvar'CLPSDbar1  [pw=indiv]
		outreg2 using "tables/ethnicaveraged", excel append dec(3) noas
	}

	foreach xvar in farmer wc skilled unskilled  lsobekscore loccscore {
		reg `xvar'CLPSDbar3 `xvar'CLPSDbar2  [pw=indiv]
		outreg2 using "tables/ethnicaveraged", excel append dec(3) noas
	}
	foreach xvar in farmer wc skilled unskilled  lsobekscore loccscore {
		
		reg `xvar'CLPSDbar3 `xvar'CLPSDbar1 [pw=indiv]
		outreg2 using "tables/ethnicaveraged", excel append dec(3) noas

		
		reg `xvar'CLPSDbar3 `xvar'CLPSDbar2 `xvar'CLPSDbar1 [pw=indiv]
		outreg2 using "tables/ethnicaveragedar2", excel append dec(3)  noas
	}

	keep bpl *CLPSD*
	save "data/collapsedvalues.dta", replace

restore

rename bpl_G11880 bpl
merge m:1 bpl using "data/collapsedvalues.dta"
drop if _merge==2
drop _merge

rename bpl bpl_G11880
save "data/cleaned188019101940.dta", replace
