/*Probit Modelling 1880-1910*/

cd "/disk/bulkw/zachward/cens1930.work/ImmigrantMulti/builddata/"

use "data/18801910handlinked.dta", clear

rename namefrst_gen31880 namefrst_gen31880orig
rename namefrst_gen31910 namefrst_gen31910orig

replace middleinit_gen31880=substr(word(namefrst_gen31880orig,2),1,1) ///
	if middleinit_gen31880=="" & length(word(namefrst_gen31880orig,2))>1

replace middleinit_gen31910=substr(word(namefrst_gen31910orig,2),1,1) ///
	if middleinit_gen31910=="" & length(word(namefrst_gen31910orig,2))>1	

gen namefrst_gen31880=word(namefrst_gen31880orig,1)
gen namefrst_gen31910=word(namefrst_gen31910orig,1)

gen exactlast=namelast_gen31880==namelast_gen31910
gen exactfirst=namefrst_gen31880==namefrst_gen31910
gen exactfirstlast=exactlast==1 & exactfirst==1

nysiis namelast_gen31910, gen(nylast1910)
nysiis namelast_gen31880, gen(nylast1880)
nysiis namefrst_gen31880, gen(nyfirst1880)
nysiis namefrst_gen31910, gen(nyfirst1910)

gen exactnyfirst=nyfirst1910==nyfirst1880
gen exactnylast=nylast1910==nylast1880
gen exactnyfirstlast=exactnyfirst==1 & exactnylast==1

foreach x of varlist namefrst_gen31910 namefrst_gen31880 namelast_gen31880 namelast_gen31910{
	gen `x'sdx=soundex_nara(`x')
}

gen exactsdxfirst=namefrst_gen31910sdx==namefrst_gen31880sdx
gen exactsdxlast=namelast_gen31880sdx==namelast_gen31910sdx
gen exactsdxfirstlast=exactsdxfirst==1 & exactsdxlast==1

gen mbplfbplmatch=mbplmatch==1 & fbplmatch==1

foreach xvar of varlist exactlast exactfirstlast exactfirst ///
	exactsdxfirst exactsdxlast exactsdxfirstlast mbplmatch fbplmatch ///
	exactnyfirst exactnylast exactnyfirstlast mbplfbplmatch{
	egen total`xvar'=total(`xvar'), by(pid_gen31880)
	replace total`xvar'=2 if total`xvar'>=2
	gen unique`xvar'=total`xvar'==1 & `xvar'==1
}

gen nylnameyob0=exactnylast & yobdiff==0
gen nylnameyob1=exactnylast	& yobdiff==1
gen nylnameyob2=exactnylast	& yobdiff>=2

gen nylnamembplfbpl=exactnylast==1 & mbplmatch==1 & fbplmatch==1

gen mbplforeign1880=mbpl_gen31880>100
gen fbplforeign1880=fbpl_gen31880>100
gen mbplforeign1910=mbpl_gen31910>100
gen fbplforeign1910=fbpl_gen31910>100
gen mbplforeignmatch=mbplforeign1880==mbplforeign1910
gen fbplforeignmatch=fbplforeign1880==fbplforeign1910

drop minitmatch
gen minitmatch=middleinit_gen31880==middleinit_gen31910 & length(middleinit_gen31880)==1 ///
	& length(middleinit_gen31910)==1

drop maxn*
egen maxn=max(n), by(pid_gen31880)
gen maxnsq=maxn^2
gen onematch=maxn==1

drop jwfirst*
jarowinkler namefrst_gen31880 namefrst_gen31910, gen(jwfirst)
gen jwfirstdist=1-jwfirst

probit link jwfirstdist jwlastdist i.yobdiff maxn maxnsq unique* ///
	mbplmatch fbplmatch minitmatch nylnameyob* i.totalexactnylast ///
	i.totalexactlast mbplfbpl* nylnamembplfbpl mbplforeignmatch fbplforeignmatch onematch
	
outreg2 using "probit18801910", replace excel
predict score18801910
gsort pid_gen31880 -score18801910

by pid_gen31880: gen n_=_n	
tab n_ if link==1	

drop maxscore maxlink 
egen maxscore=max(score18801910), by(pid_gen31880)
egen maxlink=max(link), by(pid_gen31880)




keep if n_==1 | n_==2
matrix tpr=J(1000,500,.)
matrix ppv=J(1000,500,.)

matrix rowname tpr=probability
matrix colname tpr=ratio

matrix rowname ppv=probability
matrix colname ppv=ratio

forvalues i=1/800{
forvalues j=1/100{
gen predictlink=(score18801910>=`i'/1000) & n_==1

by pid_gen31880: gen ratio=score18801910/score18801910[_n+1]

replace predictlink=0 if ratio<=`j'/10

gen tp=predictlink==1 & link==1
gen fn=predictlink==0 & link==1
gen fp=predictlink==1 & link==0
replace tp =0 if n_==2
replace fn=0 if n_==2
replace fp=0 if n_==2

egen totaltp=total(tp)
egen totallink=total(link)
gen tpr=totaltp/totallink

egen totalfp=total(fp)

gen ppvdenom=totaltp+totalfp

gen ppv=totaltp/ppvdenom

qui su ppv

matrix ppv[`i',`j']=r(mean)
qui su tpr
matrix tpr[`i',`j']=r(mean)
drop predictlink ratio tp fn fp totaltp totallink tpr totalfp ppvdenom ppv 
}
}
mat2txt, matrix(ppv) saving(ppv1880) replace
mat2txt, matrix(tpr) saving(tpr1880) replace
